from manim import *

from powermanim.components.vgrouphighlight import VGroupHighlight
from powermanim.showcase.showcasescene import ShowcaseScene


class VGroupHighlightShowcase(ShowcaseScene):
    def showcasing():
        return VGroupHighlight

    def construct(self):
        dots = [
            Dot(radius=0.25, color=color, fill_opacity=0.25).shift(i * RIGHT)
            for i, color in zip(
                range(-2, 3),
                [
                    RED,
                    GREEN,
                    BLUE,
                    YELLOW,
                    PINK,
                ],
            )
        ]

        group = VGroupHighlight(*dots, anim_run_time=1, anim_lag_ratio=0.1)
        self.add(group)
        group.highlight(self, 0)
        group.highlight(self, 1)
        group.highlight(self, [2, 3])
        group.highlight(self, [1, 3])
        group.highlight(self, [])
        group.highlight(self, [2, 4])
        group.highlight(self, [])
        self.wait(0.5)



import typing as T

from manim import *


class ArrangedBulletList(VGroup):
    def __init__(
        self,
        *rows: T.Union[Tex, Text],
        line_spacing: float = MED_LARGE_BUFF * 1.5,
        left_buff: float = MED_LARGE_BUFF * 1.5,
        shift: float = 0.0,
    ):
        """A VGroup that arranges the rows in a list of bullet points.

        Args:
            rows: A list of items to be displayed.
            line_spacing: The spacing between the rows.
            left_buff: The spacing between the left edge of the rows and the left edge of the screen.
            shift: The shift of the rows.
        """
        g_rows = (
            VGroup(*rows).arrange(DOWN, aligned_edge=LEFT, buff=line_spacing).to_edge(LEFT, buff=left_buff).shift(shift)
        )

        super().__init__(*g_rows)



from manim import *

from powermanim.showcase.showcasescene import ShowcaseScene
from powermanim.templates.bulletlist import BulletList


class BulletListShowcase(ShowcaseScene):
    def showcasing():
        return BulletList

    def construct(self):
        rows = [
            Text(row)
            for row in [
                "First row",
                "Second row",
                "Third row",
                "Fourth row",
            ]
        ]
        VGroup(*rows).set_opacity(0.5).scale(0.8)

        bullets = BulletList(
            *rows,
            scale_active=1.2,
        )
        self.add(bullets)

        bullets.also_next(self)
        bullets.also_next(self)
        bullets.also_next(self)
        bullets.also_next(self)
        bullets.clear(self)
        bullets.only_next(self)
        bullets.only_next(self)
        bullets.only_next(self)
        bullets.only_next(self)
        bullets.clear(self)
        self.wait()



from manim import *

from powermanim.layouts.arrangedbulletlist import ArrangedBulletList
from powermanim.showcase.showcasescene import ShowcaseScene


class ArrangedBulletListShowcase(ShowcaseScene):
    def showcasing():
        return ArrangedBulletList

    def construct(self):
        rows = [
            Text(row)
            for row in [
                "First row",
                "Second row",
                "Third row",
                "Fourth row",
            ]
        ]
        g_rows = VGroup(*rows).set_opacity(0.25)
        g_rows.target = ArrangedBulletList(
            *g_rows.copy(),
            line_spacing=MED_LARGE_BUFF * 1.25,
            left_buff=MED_LARGE_BUFF * 3,
        ).set_opacity(1)

        self.play(
            MoveToTarget(g_rows),
            rate_func=there_and_back_with_pause,
            run_time=3,
        )

        self.wait()
